# 2021-07-27 - Meta Stable Pool

Deployment of the `MetaStablePoolFactory`, for Meta Stable Pools of 2 tokens.

## Useful Files

- [Ethereum mainnet address](./output/mainnet.json)
- [Polygon mainnet address](./output/polygon.json)
- [Arbitrum mainnet address](./output/arbitrum.json)
- [`MetaStablePool` ABI](abi/MetaStablePool.json)
- [`MetaStablePoolFactory` ABI](abi/MetaStablePoolFactory.json)
